<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
		xmlns:web="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
                version="1.0">

<!-- ====================================================================== 
     wn-find-class.xsl                                                   

     This stylesheet defines a single public template which attempts
     to determine a matching WordNET RDF Class for a phrase.

     Note: this stylesheet relies on xmlns.com's "expiremental wordnet
     service" (http://xmlns.com/2001/08/wordnet/) which cautions that
     it should not be relied on for production grade work.

     Version : 0.1
     Date    : $Date: 2003/07/15 13:55:54 $

     Copyright (c) 2003 Aaron Straup Cope
     http://www.aaronstraupcope.com

     Documentation: http://www.aaronland.info/xsl/wordnet/wn-find-class/

     Permission to use, copy, modify and distribute this stylesheet and its 
     accompanying documentation for any purpose and without fee is hereby 
     granted in perpetuity, provided that the above copyright notice and 
     this paragraph appear in all copies.  The copyright holders make no 
     representation about the suitability of the stylesheet for any purpose.

     It is provided "as is" without expressed or implied warranty.
     ====================================================================== -->

     <xsl:variable name = "wordnet_server">http://xmlns.com/wordnet/1.6/</xsl:variable>

<!-- ====================================================================== 

     ====================================================================== -->

     <xsl:template name = "wn-find-class">
      <xsl:param name = "phrase" />

      <!-- There are probably other characters that will 
	   need to be replaced... -->

      <xsl:variable name = "term">
       <xsl:call-template name = "replace-string">
        <xsl:with-param name = "text" select = "$phrase" />
        <xsl:with-param name = "from">
         <xsl:text> </xsl:text>
        </xsl:with-param>
        <xsl:with-param name = "to">
         <xsl:text>%20</xsl:text>
        </xsl:with-param>
       </xsl:call-template>
      </xsl:variable>

      <xsl:variable name = "wn_url">
       <xsl:value-of select = "$wordnet_server" /><xsl:value-of select = "$term" />
      </xsl:variable>

      <xsl:variable name = "wn_rdf" select = "document($wn_url)" />

      <xsl:value-of select = "$wn_rdf/web:RDF/rdfs:Class/@web:about" />
     </xsl:template>

<!-- ====================================================================== 

     This template is courtesy the mighty mighty Paul Prescod:
     http://aspn.activestate.com/ASPN/Cookbook/XSLT/Recipe/65426
     ====================================================================== -->

     <xsl:template name="replace-string">
      <xsl:param name="text"/>
      <xsl:param name="from"/>
      <xsl:param name="to"/>

      <xsl:choose>
       <xsl:when test="contains($text, $from)">

	<xsl:variable name="before" select="substring-before($text, $from)"/>
	<xsl:variable name="after" select="substring-after($text, $from)"/>
	<xsl:variable name="prefix" select="concat($before, $to)"/>

	<xsl:value-of select="$before"/>
	<xsl:value-of select="$to"/>
        <xsl:call-template name="replace-string">
	 <xsl:with-param name="text" select="$after"/>
	 <xsl:with-param name="from" select="$from"/>
	 <xsl:with-param name="to" select="$to"/>
	</xsl:call-template>
       </xsl:when> 
       <xsl:otherwise>
        <xsl:value-of select="$text"/>  
       </xsl:otherwise>
      </xsl:choose>            
     </xsl:template>

<!-- ====================================================================== 
     FIN // $Id: wn-find-class.xsl,v 1.1 2003/07/15 13:55:54 asc Exp $
     ====================================================================== -->

</xsl:stylesheet>

